@@ -20,9 +20,9 @@
 #include "Algorithm.h"
 using namespace Music;
 
-Algorithm::Algorithm(double volume_treshold)
-: m_volume_treshold(volume_treshold)
-, m_volume_max(0.0)
+Algorithm::Algorithm()
+: m_amplitude_treshold(0.0)
+, m_max_amplitude(0.0)
 {
 }
 
@@ -30,19 +30,7 @@ Algorithm::~Algorithm()
 {
 }
 
-Transform::Transform(double volume_treshold, double components_treshold, int size)
-: Algorithm(volume_treshold)
-, m_components_treshold(components_treshold)
-, m_components(size)
-, m_first_fond(-1)
-, m_is_fondamental(size)
-{
-}
-Transform::Transform(double volume_treshold, double components_treshold)
-: Algorithm(volume_treshold)
-, m_components_treshold(components_treshold)
-, m_components(GetNbSemitones())
-, m_first_fond(-1)
-, m_is_fondamental(GetNbSemitones())
+Transform::Transform()
+: m_component_treshold(0.0)
 {
 }
