@@ -51,15 +51,18 @@ using namespace std;
 #include <Music/Convolution.h>
 using namespace Music;
 #include "modules/View.h"
+#include "qthelper.h"
+
+#include "aboutbox.h"
 
 CustomInstrumentTunerForm::CustomInstrumentTunerForm()
 : m_config_form(this)
 , m_capture_thread("fmit")
-, m_timer_refresh(this)
 , m_algo_combedfft(NULL)
+, m_settings("fmit", "fmit", "009801")	// not necessarily equal to the soft version
+, m_timer_refresh(this)
 , m_range_filter(&m_dummy_range_filter)
 , m_quantizer(&m_latency_quantizer)
-, m_settings("fmit", "fmit", "009801")	// not necessarily equal to the soft version
 {
 	setupUi(this);
 
@@ -67,13 +70,16 @@ CustomInstrumentTunerForm::CustomInstrumentTunerForm()
 	viewsCaption->setDefaultWidget(new QLabel(tr("Views"), ui_tbViews));
 	ui_tbViews->addAction(viewsCaption);*/
 
+    //saveSettingsAction->setIcon(style()->standardIcon(QStyle::SP_DialogSaveButton));
+    //pauseAction->setIcon(style()->standardIcon(QStyle::SP_MediaPause));
+
 	View::s_settings = &m_settings;
 	m_settings.add(m_config_form.ui_chkFullScreen);
 	m_settings.add(m_config_form.ui_chkAutoSaveOnExit);
 	m_settings.add(m_config_form.ui_chkShowA4Offset);
 
 	m_settings.add(m_config_form.ui_cbTuning);
-	m_settings.add(m_config_form.ui_cbTonality);
+	m_settings.add(m_config_form.ui_spinTransposition);
 	m_settings.add(m_config_form.ui_cbNotesName);
 	m_settings.add(ui_spinAFreq);
 	m_settings.add(ui_spinA3Offset);
@@ -125,7 +131,7 @@ CustomInstrumentTunerForm::CustomInstrumentTunerForm()
 
 	m_algo_combedfft = new CombedFT();
 
-	for(int i=0; i<m_capture_thread.getTransports().size(); i++)
+    for(int i=0; i<int(m_capture_thread.getTransports().size()); i++)
 		m_config_form.ui_cbTransports->addItem(m_capture_thread.getTransports()[i]->getName());
 
 	if(m_capture_thread.getTransports().empty())
@@ -141,6 +147,9 @@ CustomInstrumentTunerForm::CustomInstrumentTunerForm()
 	m_config_form.ui_grpJACK->hide();
 	m_config_form.ui_grpPortAudio->hide();
 	m_config_form.ui_grpOSS->hide();
+    m_config_form.ui_grpQt->hide();
+
+    m_config_form.ui_grpRangeFiltering->hide();
 
 	ui_lblA3Offset->hide();
 	ui_spinA3Offset->hide();
@@ -171,8 +180,8 @@ CustomInstrumentTunerForm::CustomInstrumentTunerForm()
 	// link scales
 	connect(m_dialTune->setting_spinScale, SIGNAL(valueChanged(int)), m_glErrorHistory->setting_spinScale, SLOT(setValue(int)));
 	connect(m_glErrorHistory->setting_spinScale, SIGNAL(valueChanged(int)), m_dialTune->setting_spinScale, SLOT(setValue(int)));
-	connect(m_dialTune->setting_useCents, SIGNAL(toggled(bool)), m_glErrorHistory->setting_useCents, SLOT(setOn(bool)));
-	connect(m_glErrorHistory->setting_useCents, SIGNAL(toggled(bool)), m_dialTune->setting_useCents, SLOT(setOn(bool)));
+    connect(m_dialTune->setting_useCents, SIGNAL(toggled(bool)), m_glErrorHistory->setting_useCents, SLOT(setChecked(bool)));
+    connect(m_glErrorHistory->setting_useCents, SIGNAL(toggled(bool)), m_dialTune->setting_useCents, SLOT(setChecked(bool)));
 
 	m_glVolumeHistory = new GLVolumeHistory(centralWidget());
 	connect(m_config_form.ui_spinVolumeTreshold, SIGNAL(valueChanged(int)), m_glVolumeHistory, SLOT(setVolumeTreshold(int)));
@@ -181,9 +190,9 @@ CustomInstrumentTunerForm::CustomInstrumentTunerForm()
 	ui_volumeLayout->addWidget(m_glVolumeHistory);
 
 	// link keep settings
-	connect(ui_btnKeepErrorHistory, SIGNAL(toggled(bool)), m_glErrorHistory->setting_keep, SLOT(setOn(bool)));
-	connect(m_glErrorHistory->setting_keep, SIGNAL(toggled(bool)), m_glVolumeHistory->setting_keep, SLOT(setOn(bool)));
-	connect(m_glErrorHistory->setting_keep, SIGNAL(toggled(bool)), ui_btnKeepErrorHistory, SLOT(setOn(bool)));
+    connect(ui_btnKeepErrorHistory, SIGNAL(toggled(bool)), m_glErrorHistory->setting_keep, SLOT(setChecked(bool)));
+    connect(m_glErrorHistory->setting_keep, SIGNAL(toggled(bool)), m_glVolumeHistory->setting_keep, SLOT(setChecked(bool)));
+    connect(m_glErrorHistory->setting_keep, SIGNAL(toggled(bool)), ui_btnKeepErrorHistory, SLOT(setChecked(bool)));
 
 	m_glSample = new GLSample(centralWidget());
 	connect(m_glSample->setting_show, SIGNAL(toggled(bool)), this, SLOT(update_views()));
@@ -213,11 +222,11 @@ CustomInstrumentTunerForm::CustomInstrumentTunerForm()
 
 	connect(m_dialTune->setting_spinScale, SIGNAL(valueChanged(int)), m_glStatistics->setting_spinScale, SLOT(setValue(int)));
 	connect(m_glStatistics->setting_spinScale, SIGNAL(valueChanged(int)), m_dialTune->setting_spinScale, SLOT(setValue(int)));
-	connect(m_dialTune->setting_useCents, SIGNAL(toggled(bool)), m_glStatistics->setting_useCents, SLOT(setOn(bool)));
-	connect(m_glStatistics->setting_useCents, SIGNAL(toggled(bool)), m_dialTune->setting_useCents, SLOT(setOn(bool)));
+    connect(m_dialTune->setting_useCents, SIGNAL(toggled(bool)), m_glStatistics->setting_useCents, SLOT(setChecked(bool)));
+    connect(m_glStatistics->setting_useCents, SIGNAL(toggled(bool)), m_dialTune->setting_useCents, SLOT(setChecked(bool)));
 
-	connect(m_dialTune->setting_showTolerance, SIGNAL(toggled(bool)), m_glStatistics->setting_showTolerance, SLOT(setOn(bool)));
-	connect(m_glStatistics->setting_showTolerance, SIGNAL(toggled(bool)), m_dialTune->setting_showTolerance, SLOT(setOn(bool)));
+    connect(m_dialTune->setting_showTolerance, SIGNAL(toggled(bool)), m_glStatistics->setting_showTolerance, SLOT(setChecked(bool)));
+    connect(m_glStatistics->setting_showTolerance, SIGNAL(toggled(bool)), m_dialTune->setting_showTolerance, SLOT(setChecked(bool)));
 
     connect(&m_config_form, SIGNAL(accepted()), this, SLOT(configure_ok()));
     connect(&m_config_form, SIGNAL(rejected()), this, SLOT(configure_cancel()));
@@ -225,7 +234,7 @@ CustomInstrumentTunerForm::CustomInstrumentTunerForm()
 	connect(m_config_form.ui_spinMinHT, SIGNAL(valueChanged(int)), this, SLOT(noteRangeChanged()));
 	connect(m_config_form.ui_spinMaxHT, SIGNAL(valueChanged(int)), this, SLOT(noteRangeChanged()));
 	connect(m_config_form.ui_cbTuning, SIGNAL(highlighted(int)), this, SLOT(noteRangeChanged()));
-	connect(m_config_form.ui_cbTonality, SIGNAL(highlighted(int)), this, SLOT(noteRangeChanged()));
+	connect(m_config_form.ui_spinTransposition, SIGNAL(valueChanged(int)), this, SLOT(transpositionChanged()));
 	connect(m_config_form.ui_cbNotesName, SIGNAL(highlighted(int)), this, SLOT(noteRangeChanged()));
 	connect(m_config_form.ui_btnAutoDetect, SIGNAL(clicked()), this, SLOT(autoDetectTransport()));
 	connect(m_config_form.ui_cbTransports, SIGNAL(activated(const QString&)), this, SLOT(selectTransport(const QString&)));
@@ -243,13 +252,15 @@ CustomInstrumentTunerForm::CustomInstrumentTunerForm()
 	if(m_config_form.ui_chkFullScreen->isChecked())
 		toggleFullScreen();
 
+    m_config_form.adjustSize();
+
 	m_time_refresh_views.start();
 	m_time_refresh.start();
 	m_time.start();
 	connect((QObject*)&m_timer_refresh, SIGNAL(timeout()), this, SLOT(refresh()));
 	m_timer_refresh.start(m_config_form.ui_spinRefreshTime->value());
 
-//     cerr << __FILE__ << " " << __LINE__ << endl;
+//     cout << __FILE__ << " " << __LINE__ << endl;
 }
 
 void CustomInstrumentTunerForm::transportChanged(const QString& name)
@@ -265,11 +276,13 @@ void CustomInstrumentTunerForm::selectTransport(const QString& name)
 	m_config_form.ui_grpJACK->hide();
 	m_config_form.ui_grpPortAudio->hide();
 	m_config_form.ui_grpOSS->hide();
+    m_config_form.ui_grpQt->hide();
 
 	if(name=="ALSA")			m_config_form.ui_grpALSA->show();
 	else if(name=="JACK")		m_config_form.ui_grpJACK->show();
 	else if(name=="PortAudio")	m_config_form.ui_grpPortAudio->show();
 	else if(name=="OSS")		m_config_form.ui_grpOSS->show();
+    else if(name=="Qt")         m_config_form.ui_grpQt->show();
 }
 void CustomInstrumentTunerForm::autoDetectTransport()
 {
@@ -296,15 +309,23 @@ void CustomInstrumentTunerForm::toggleFullScreen()
 
 void CustomInstrumentTunerForm::noteRangeChanged()
 {
-	//	cerr << "CustomInstrumentTunerForm::noteRangeChanged" << endl;
+    //	cout << "CustomInstrumentTunerForm::noteRangeChanged" << endl;
 
 	m_config_form.ui_txtMinHT->setText(QString::fromStdString(h2n(m_config_form.ui_spinMinHT->value())) + " = " + QString::number(h2f(m_config_form.ui_spinMinHT->value())) + " hz");
 	m_config_form.ui_txtMaxHT->setText(QString::fromStdString(h2n(m_config_form.ui_spinMaxHT->value())) + " = " + QString::number(h2f(m_config_form.ui_spinMaxHT->value())) + " hz");
 }
 
+void CustomInstrumentTunerForm::transpositionChanged()
+{
+	m_config_form.ui_lblTransposition->setText(
+			QString::fromStdString(h2n(-9, GetNotesName(), 0, CHROMATIC, true))
+			+ " → " +
+			QString::fromStdString(h2n(-9, GetNotesName(), m_config_form.ui_spinTransposition->value(), CHROMATIC, true)));
+}
+
 void CustomInstrumentTunerForm::errorRaised(const QString& error)
 {
-	//	cerr << "CustomInstrumentTunerForm::errorRaised " << error << endl;
+    //	cout << "CustomInstrumentTunerForm::errorRaised " << error << endl;
 
 	statusBar()->showMessage(QString("ERROR: ")+error);
 
@@ -315,11 +336,11 @@ void CustomInstrumentTunerForm::errorRaised(const QString& error)
 
 void CustomInstrumentTunerForm::samplingRateChanged(int sampling_rate)
 {
-	cerr << "CustomInstrumentTunerForm::samplingRateChanged " << sampling_rate << endl;
+//	cout << "CustomInstrumentTunerForm::samplingRateChanged " << sampling_rate << endl;
 
 	Music::SetSamplingRate(sampling_rate);
 
-        m_rect_range_filter.reset(int(GetSamplingRate()/2000.0));
+    m_rect_range_filter.reset(int(GetSamplingRate()/2000.0));
 //         m_fir_range_filter.setImpulseResponse(fir1_lowpass(400, 2/400));
 // 	m_rect_range_filter.reset(int(GetSamplingRate()/h2f(GetSemitoneMin())));
     m_glFT->spinWinLengthChanged(m_glFT->setting_winlen->value());
@@ -335,7 +356,7 @@ void CustomInstrumentTunerForm::ui_spinAFreq_valueChanged(int AFreq)
 	if(m_config_form.ui_chkShowA4Offset->isChecked())
 		A = h2f(ui_spinA3Offset->value()*1/100.0f, A);
 	Music::SetAFreq(A);
-//	cerr << A << endl;
+//	cout << A << endl;
 }
 void CustomInstrumentTunerForm::ui_spinAOffset_valueChanged(int offset)
 {
@@ -343,12 +364,12 @@ void CustomInstrumentTunerForm::ui_spinAOffset_valueChanged(int offset)
 	if(m_config_form.ui_chkShowA4Offset->isChecked())
 		A = h2f(offset*1/100.0f, ui_spinAFreq->value());
 	Music::SetAFreq(A);
-//	cerr << A << endl;
+//	cout << A << endl;
 }
 
 void CustomInstrumentTunerForm::tuningFreqChanged(float freq)
 {
-	//	cerr << "CustomInstrumentTunerForm::tuningFreqChanged " << freq << endl;
+    //	cout << "CustomInstrumentTunerForm::tuningFreqChanged " << freq << endl;
 
 	if(freq==0.0f)
 	{
@@ -395,17 +416,17 @@ void CustomInstrumentTunerForm::refresh()
 	int limit = int( m_capture_thread.getSamplingRate() /
 			(1.0/(m_config_form.ui_spinRefreshTime->value()/1000.0) - 1));
 
-// 	cerr << "REFRESH ";
+// 	cout << "REFRESH ";
 
 	m_capture_thread.lock();
-//     cerr << "CustomInstrumentTunerForm::refresh locked, values to read=" << m_capture_thread.m_values.size() << endl;
+//     cout << "CustomInstrumentTunerForm::refresh locked, values to read=" << m_capture_thread.m_values.size() << endl;
 	int nb_new_data = 0;
 	while(!m_capture_thread.m_values.empty() &&
-			  (m_capture_thread.m_values.size()>m_capture_thread.getPacketSizeSinceLastLock() || nb_new_data<limit))
-	{
-// 		cerr << m_capture_thread.m_values.back() << " ";
+              (int(m_capture_thread.m_values.size())>m_capture_thread.getPacketSizeSinceLastLock() || nb_new_data<limit))
+    {
+// 		cout << m_capture_thread.m_values.back() << " ";
 		double value = (*m_range_filter)(m_capture_thread.m_values.back());
-// 		cerr << value << " ";
+// 		cout << value << " ";
 		m_capture_thread.m_values.pop_back();
 
 		m_queue.push_front(value);
@@ -415,9 +436,9 @@ void CustomInstrumentTunerForm::refresh()
 		nb_new_data++;
 	}
 	m_capture_thread.unlock();
-//     cerr << "CustomInstrumentTunerForm::refresh unlocked" << endl;
+//     cout << "CustomInstrumentTunerForm::refresh unlocked" << endl;
 
-// 	cerr << endl;
+// 	cout << endl;
 
 	int max_size = max(m_range_filter->getLength(), max(m_glGraph->getLength(), m_algo_combedfft->getMinSize()));
 	while(!m_queue.empty() && int(m_queue.size())>max_size)
@@ -468,7 +489,7 @@ void CustomInstrumentTunerForm::refresh()
 			}
 		}
 
-// 		cerr << "2) test freq=" << m_test_freq <<endl;
+// 		cout << "2) test freq=" << m_test_freq <<endl;
 
 		m_quantizer->quantize(freq);
 
@@ -533,7 +554,9 @@ void CustomInstrumentTunerForm::refresh()
 
 void CustomInstrumentTunerForm::noteStarted(double freq, double dt)
 {
-// 	cerr << "CustomInstrumentTunerForm::noteStarted " << freq << "," << dt << endl;
+    Q_UNUSED(freq)
+    Q_UNUSED(dt)
+// 	cout << "CustomInstrumentTunerForm::noteStarted " << freq << "," << dt << endl;
 
 	// set the compared freq
 	if(m_microtonalView->setting_show->isChecked() && m_microtonalView->hasTuningFreqSelected())
@@ -566,8 +589,10 @@ void CustomInstrumentTunerForm::noteStarted(double freq, double dt)
 }
 void CustomInstrumentTunerForm::noteFinished(double freq, double dt)
 {
+    Q_UNUSED(freq)
+    Q_UNUSED(dt)
 	m_compared_freq = 0.0;
-// 	cerr << "CustomInstrumentTunerForm::noteFinished " << freq << "," << dt << endl;
+// 	cout << "CustomInstrumentTunerForm::noteFinished " << freq << "," << dt << endl;
 }
 
 void CustomInstrumentTunerForm::refresh_data_sample()
@@ -590,14 +615,17 @@ void CustomInstrumentTunerForm::refresh_data_harmonics()
 			m_glFreqStruct->setting_show->isChecked()))
 		return;
 
-	vector<Harmonic> harms = GetHarmonicStruct(m_algo_combedfft->m_plan.out, m_freq, m_glFreqStruct->m_components.size(), m_algo_combedfft->getZeroPaddingFactor());
+    for(int i=0; i<int(m_glFreqStruct->m_components.size()); i++)
+        m_glFreqStruct->m_components[i] = -1e6;
 
-	m_glFreqStruct->m_components_max = 0.0;
-	for(int i=0; i<harms.size(); i++)
+    vector<Harmonic> harms = GetHarmonicStruct(m_algo_combedfft->m_plan.out, m_freq, m_glFreqStruct->m_components.size(), m_algo_combedfft->getZeroPaddingFactor(), 0.1, true);
+
+    m_glFreqStruct->m_components_max = 0.0;
+    for(int i=0; i<int(harms.size()); i++)
 	{
-		if(harms[i].harm_number<m_glFreqStruct->m_components.size())
+        if(harms[i].harm_number<=int(m_glFreqStruct->m_components.size()))
 		{
-			m_glFreqStruct->m_components[harms[i].harm_number-1] = 20*log10(harms[i].mod/0.001);
+            m_glFreqStruct->m_components[harms[i].harm_number-1] = 20*log10(harms[i].mod*1000.0);
 
  			m_glFreqStruct->m_components_max = max(m_glFreqStruct->m_components_max, m_glFreqStruct->m_components[i]);
 		}
@@ -606,33 +634,33 @@ void CustomInstrumentTunerForm::refresh_data_harmonics()
 
 void CustomInstrumentTunerForm::refresh_views()
 {
-// 	cerr << "CustomInstrumentTunerForm::refresh_views " << endl;
+// 	cout << "CustomInstrumentTunerForm::refresh_views " << endl;
 
-//	m_dialTune->repaint();
+	m_dialTune->repaint();
 
 	if(m_glGraph->setting_show->isChecked())
-		m_glGraph->updateGL();
+		m_glGraph->update();
 
 	if(m_glErrorHistory->setting_show->isChecked())
-		m_glErrorHistory->updateGL();
+		m_glErrorHistory->update();
 
 	if(m_glVolumeHistory->setting_show->isChecked())
-		m_glVolumeHistory->updateGL();
+		m_glVolumeHistory->update();
 
 	if(m_microtonalView->setting_show->isChecked())
 		m_microtonalView->update();
 
 	if(m_glSample->setting_show->isChecked())
-		m_glSample->updateGL();
+		m_glSample->update();
 
 	if(m_glFreqStruct->setting_show->isChecked())
-		m_glFreqStruct->updateGL();
+		m_glFreqStruct->update();
 
 	if(m_glFT->setting_show->isChecked())
-		m_glFT->updateGL();
+		m_glFT->update();
 
 	if(m_glStatistics->setting_show->isChecked())
-		m_glStatistics->updateGL();
+		m_glStatistics->update();
 
 	m_time_refresh_views.start();
 }
@@ -645,6 +673,7 @@ void CustomInstrumentTunerForm::keyPressEvent(QKeyEvent * e)
 
 void CustomInstrumentTunerForm::resizeEvent(QResizeEvent* e)
 {
+    Q_UNUSED(e)
 	update_views();
 }
 
@@ -683,8 +712,9 @@ void CustomInstrumentTunerForm::configure()
     m_capture_thread.stopCapture();
 
 	noteRangeChanged();
+	transpositionChanged();
 
-	if(m_capture_thread.getCurrentTransportIndex()<m_config_form.ui_cbTransports->count());
+    if(m_capture_thread.getCurrentTransportIndex()<m_config_form.ui_cbTransports->count())
 		m_config_form.ui_cbTransports->setCurrentIndex(m_capture_thread.getCurrentTransportIndex());
 
 #ifdef CAPTURE_JACK
@@ -720,7 +750,7 @@ void CustomInstrumentTunerForm::configure()
 		}
 		catch(QString error)
 		{
-			cerr << "CustomInstrumentTunerForm: ERROR: " << error.toStdString() << endl;
+            cout << "CustomInstrumentTunerForm: ERROR: " << error.toStdString() << endl;
 		}
 		Pa_Terminate();
 	}
@@ -734,6 +764,31 @@ void CustomInstrumentTunerForm::configure()
 	m_config_form.ui_grpOSS->setTitle(m_capture_thread.getTransport("OSS")->getDescription());
 	m_config_form.ui_spinOSSSamplingRate->setValue(m_capture_thread.getSamplingRate());
 #endif
+#ifdef CAPTURE_QT
+    m_config_form.ui_grpQt->setTitle(m_capture_thread.getTransport("Qt")->getDescription());
+    m_config_form.ui_spinQtSamplingRate->setValue(m_capture_thread.getSamplingRate());
+    {
+        QString saved_device = m_settings.value(m_config_form.ui_cbQtDeviceName->objectName(), "default").toString();
+        try
+        {
+            QList<QAudioDeviceInfo> devices = QAudioDeviceInfo::availableDevices(QAudio::AudioInput);
+
+            int current_index = -1;
+            m_config_form.ui_cbQtDeviceName->clear();
+            for(int i=0; i<devices.count(); i++) {
+                m_config_form.ui_cbQtDeviceName->addItem(devices.at(i).deviceName());
+                if(devices.at(i).deviceName()==m_capture_thread.getTransport("Qt")->getSource())
+                    current_index = i;
+            }
+            if(current_index!=-1)
+                m_config_form.ui_cbQtDeviceName->setCurrentIndex(current_index);
+        }
+        catch(QString error)
+        {
+            cout << "CustomInstrumentTunerForm: ERROR: " << error.toStdString() << endl;
+        }
+    }
+#endif
 
     m_config_form.adjustSize();
 	m_config_form.show();
@@ -767,28 +822,42 @@ void CustomInstrumentTunerForm::configure_ok()
 		break;
 	}
 
-	if(m_config_form.ui_cbTonality->currentIndex()==0)		SetTonality(0);
-	else if(m_config_form.ui_cbTonality->currentIndex()==1)	SetTonality(+2);
-	else													SetTonality(-3);
+	SetTransposition(m_config_form.ui_spinTransposition->value());
 
 	if(m_config_form.ui_cbNotesName->currentIndex()==0)		SetNotesName(LOCAL_ANGLO);
-	else													SetNotesName(LOCAL_LATIN);
+	if(m_config_form.ui_cbNotesName->currentIndex()==1)		SetNotesName(LOCAL_LATIN);
+	if(m_config_form.ui_cbNotesName->currentIndex()==2)		SetNotesName(LOCAL_GERMAN);
+	if(m_config_form.ui_cbNotesName->currentIndex()==3)		SetNotesName(LOCAL_HINDUSTANI);
+	if(m_config_form.ui_cbNotesName->currentIndex()==4)		SetNotesName(LOCAL_BYZANTINE);
 	m_microtonalView->notesNameChanged();
 	m_microtonalView->setAFreq(Music::GetAFreq());
 
+	update_localized_note_names();
+
 	SetSemitoneBounds(m_config_form.ui_spinMinHT->value(), m_config_form.ui_spinMaxHT->value());
 
-	ui_spinA3Offset->setShown(m_config_form.ui_chkShowA4Offset->isChecked());
-	ui_lblA3Offset->setShown(m_config_form.ui_chkShowA4Offset->isChecked());
+    ui_spinA3Offset->setVisible(m_config_form.ui_chkShowA4Offset->isChecked());
+    ui_lblA3Offset->setVisible(m_config_form.ui_chkShowA4Offset->isChecked());
 
 	//	if(m_note!=-1000)
 	//		ui_txtNote->setText(h2n(m_note));
 
 	//	m_dialTune->setError(-10.0f);
 
-// 	cerr << "b" << endl;
+// 	cout << "b" << endl;
 
 	// Capture
+#ifdef CAPTURE_QT
+    if(m_config_form.ui_cbTransports->currentText()=="Qt")
+    {
+        m_capture_thread.selectTransport("Qt");
+        m_capture_thread.setSource(m_config_form.ui_cbQtDeviceName->currentText());
+        if(m_config_form.ui_chkQtSamplingRateMax->isChecked())
+            m_capture_thread.setSamplingRate(CaptureThread::SAMPLING_RATE_MAX);
+        else
+            m_capture_thread.setSamplingRate(m_config_form.ui_spinQtSamplingRate->value());
+    }
+#endif
 #ifdef CAPTURE_ALSA
 	if(m_config_form.ui_cbTransports->currentText()=="ALSA")
 	{
@@ -839,7 +908,7 @@ void CustomInstrumentTunerForm::configure_ok()
 	m_glGraph->m_treshold = invlp(m_config_form.ui_spinVolumeTreshold->value());
 	m_glGraph->clearValues();
 
-// 	cerr << "c" << endl;
+// 	cout << "c" << endl;
 
 	if(m_config_form.ui_grpRangeFiltering->isChecked())
 	{
@@ -864,7 +933,7 @@ void CustomInstrumentTunerForm::configure_ok()
 	m_algo_combedfft->setAmplitudeTreshold(invlp(double(m_config_form.ui_spinVolumeTreshold->value())));
 	m_algo_combedfft->setComponentTreshold(invlp(double(m_config_form.ui_spinVolumeTreshold->value())));
 
-// 	cerr << "d" << endl;
+// 	cout << "d" << endl;
 
 	// Quantizers
 	m_quantizer->reset();
@@ -876,7 +945,7 @@ void CustomInstrumentTunerForm::configure_ok()
 	else
 		m_quantizer = &m_dummy_quantizer;
 
-// 	cerr << invlp(-m_config_form.ui_spinCombedFFTAudibilityRatio->value()) << endl;
+// 	cout << invlp(-m_config_form.ui_spinCombedFFTAudibilityRatio->value()) << endl;
 
 	if(!pauseAction->isChecked() && !m_capture_thread.isCapturing())
 		m_capture_thread.startCapture();
@@ -895,13 +964,16 @@ void CustomInstrumentTunerForm::saveSettings()
 
 	// sound capture
 	m_settings.setValue(m_config_form.ui_cbTransports->objectName(), m_config_form.ui_cbTransports->currentText());
+#ifdef CAPTURE_QT
+    m_settings.setValue(m_config_form.ui_cbQtDeviceName->objectName(), m_config_form.ui_cbQtDeviceName->currentText());
+#endif
 #ifdef CAPTURE_PORTAUDIO
 	m_settings.setValue(m_config_form.ui_cbPortAudioDeviceName->objectName(), m_config_form.ui_cbPortAudioDeviceName->currentText());
 #endif
 }
 void CustomInstrumentTunerForm::loadSettings()
 {
-//     cerr << __FILE__ << ":" << __LINE__ << endl;
+//     cout << __FILE__ << ":" << __LINE__ << endl;
 
 	m_settings.load();
 	View::loadAll();
@@ -918,35 +990,62 @@ void CustomInstrumentTunerForm::loadSettings()
 			if(m_config_form.ui_cbTransports->itemText(i)==saved_transport)
 				m_config_form.ui_cbTransports->setCurrentIndex(i);
 
+#ifdef CAPTURE_QT
+    {
+        QString saved_device = m_settings.value(m_config_form.ui_cbQtDeviceName->objectName(), "default").toString();
+        try
+        {
+            QList<QAudioDeviceInfo> devices = QAudioDeviceInfo::availableDevices(QAudio::AudioInput);
+
+            int saved_index = -1;
+            m_config_form.ui_cbQtDeviceName->clear();
+            for(int i=0; i<devices.count(); i++)
+            {
+                m_config_form.ui_cbQtDeviceName->addItem(devices.at(i).deviceName());
+                if(devices.at(i).deviceName()==saved_device)
+                    saved_index = i;
+            }
+            if(saved_index!=-1)
+                m_config_form.ui_cbQtDeviceName->setCurrentIndex(saved_index);
+        }
+        catch(QString error)
+        {
+    //		cout << "CustomInstrumentTunerForm: ERROR: " << error << endl;
+        }
+    }
+#endif
+
 #ifdef CAPTURE_PORTAUDIO
-	QString saved_device = m_settings.value(m_config_form.ui_cbPortAudioDeviceName->objectName(), "default").toString();
-	try
-	{
-		PaError err;
-		err = Pa_Initialize();
-		if(err != paNoError)
-			throw QString("PortAudio: CustomInstrumentTunerForm::loadSettings:Pa_Initialize ")+Pa_GetErrorText(err);
-		int	numDevices = Pa_GetDeviceCount();
-//         cerr << "PortAudio devices:"<< endl;
-        int saved_index = -1;
-		m_config_form.ui_cbPortAudioDeviceName->clear();
-		const PaDeviceInfo* deviceInfo;
-		for(int i=0; i<numDevices; i++)
-		{
-			deviceInfo = Pa_GetDeviceInfo(i);
-//             cerr << "    " << QString(deviceInfo->name).toStdString() << endl;
-			m_config_form.ui_cbPortAudioDeviceName->addItem(QString(deviceInfo->name));
-			if(QString(deviceInfo->name)==saved_device)
-				saved_index = i;
-		}
-		if(saved_index!=-1)
-			m_config_form.ui_cbPortAudioDeviceName->setCurrentIndex(saved_index);
+    {
+        QString saved_device = m_settings.value(m_config_form.ui_cbPortAudioDeviceName->objectName(), "default").toString();
+        try
+        {
+            PaError err;
+            err = Pa_Initialize();
+            if(err != paNoError)
+                throw QString("PortAudio: CustomInstrumentTunerForm::loadSettings:Pa_Initialize ")+Pa_GetErrorText(err);
+            int	numDevices = Pa_GetDeviceCount();
+    //         cout << "PortAudio devices:"<< endl;
+            int saved_index = -1;
+            m_config_form.ui_cbPortAudioDeviceName->clear();
+            const PaDeviceInfo* deviceInfo;
+            for(int i=0; i<numDevices; i++)
+            {
+                deviceInfo = Pa_GetDeviceInfo(i);
+    //             cout << "    " << QString(deviceInfo->name).toStdString() << endl;
+                m_config_form.ui_cbPortAudioDeviceName->addItem(QString(deviceInfo->name));
+                if(QString(deviceInfo->name)==saved_device)
+                    saved_index = i;
+            }
+            if(saved_index!=-1)
+                m_config_form.ui_cbPortAudioDeviceName->setCurrentIndex(saved_index);
+        }
+        catch(QString error)
+        {
+    //		cout << "CustomInstrumentTunerForm: ERROR: " << error << endl;
+        }
+        Pa_Terminate();
     }
-	catch(QString error)
-	{
-//		cerr << "CustomInstrumentTunerForm: ERROR: " << error << endl;
-	}
-	Pa_Terminate();
 #endif
 }
 
@@ -971,63 +1070,91 @@ void CustomInstrumentTunerForm::restoreFactorySettings()
 
 void CustomInstrumentTunerForm::helpAbout()
 {
-	QString text;
-	text = "<h2>Free Music Instrument Tuner</h2>";
-	text += tr("<h3>Version ")+PACKAGE_VERSION;
-	text += tr("</h3><p><h3>Website:</h3><p>homepage: <a href=\"http://gillesdegottex.github.io/fmit/\">http://gillesdegottex.github.io/fmit/</a>");
-	text += tr("<p>development site: <a href=\"http://github.com/gillesdegottex/fmit\">http://github.com/gillesdegottex/fmit</a>");
-	text += tr("<p>donation link: <a href=\"http://gillesdegottex.github.io/fmit/\">http://gillesdegottex.github.io/fmit/</a>");
-	text += tr("<p><h3>Author:</h3><p>Gilles Degottex <a href=\"mailto:gilles.degottex@gmail.com\">gilles.degottex@gmail.com</a>");
-#ifdef PACKAGER_STRING
-	if(PACKAGER_STRING!="")
-		text += tr("<p><h3>Packager:</h3><p>")+QString(PACKAGER_STRING).replace(QChar('<'),"[").replace(QChar('>'),"]");
-#endif
+    AboutBox box(this);
+    box.exec();
 
-	QDialog about_dlg(this);
+//    QString text;
+//    text = "<h2>Free Music Instrument Tuner</h2>";
 
-	QTextBrowser* textBrowser1;
-	QPushButton* pushButton1;
-	QVBoxLayout* Form2Layout;
-	QHBoxLayout* layout1;
-	QSpacerItem* spacer1;
-	QSpacerItem* spacer2;
+//    QString	fmitversion;
+//    QString fmitversiongit(STR(FMITVERSIONGIT));
+//    if(fmitversiongit.length()>0) {
+//        fmitversion = tr("Version ") + fmitversiongit;
+//    }
+//    else {
+//        QFile readmefile(":/fmit/README.txt");
+//        readmefile.open(QFile::ReadOnly | QFile::Text);
+//        QTextStream readmefilestream(&readmefile);
+//        readmefilestream.readLine();
+//        readmefilestream.readLine();
+//        readmefilestream.readLine();
+//        fmitversion = readmefilestream.readLine().simplified();
+//    }
+//    text += tr("<h3>")+fmitversion;
 
-	about_dlg.setObjectName( tr("about_box") );
-	about_dlg.setWindowTitle( tr("About Free Music Instrument Tuner") );
+//    text += tr(" (compiled by ")+QString(COMPILER)+tr(" for ");
+//    #ifdef Q_PROCESSOR_X86_32
+//      text += "32bits";
+//    #endif
+//    #ifdef Q_PROCESSOR_X86_64
+//      text += "64bits";
+//    #endif
+//    text += ")";
 
-	Form2Layout = new QVBoxLayout( &about_dlg );
-	Form2Layout->setMargin(11);
-	Form2Layout->setSpacing(6);
-	about_dlg.setLayout( Form2Layout );
+//    text += "</h3><p><h3>"+tr("Website: ")+"</h3><p>"+tr("Homepage: ")+"<a href=\"http://gillesdegottex.github.io/fmit/\">http://gillesdegottex.github.io/fmit/</a>";
+//    text += "<p>"+tr("Development site: ")+"<a href=\"http://github.com/gillesdegottex/fmit\">http://github.com/gillesdegottex/fmit</a>";
+////	text += tr("<p>donation link: <a href=\"http://gillesdegottex.github.io/fmit/\">http://gillesdegottex.github.io/fmit/</a>");
+//    text += "<p><h3>"+tr("Author: ")+"</h3><p>Gilles Degottex <a href=\"mailto:gilles.degottex@gmail.com\">gilles.degottex@gmail.com</a>";
+//#ifdef PACKAGER_STRING
+//	if(PACKAGER_STRING!="")
+//        text += "<p><h3>"+tr("Packager: ")+"</h3><p>"+QString(PACKAGER_STRING).replace(QChar('<'),"[").replace(QChar('>'),"]");
+//#endif
 
-	textBrowser1 = new QTextBrowser( &about_dlg );
-	textBrowser1->setHtml(text);
-	textBrowser1->setOpenExternalLinks(true);
-	textBrowser1->setWordWrapMode(QTextOption::NoWrap);
-	textBrowser1->setHorizontalScrollBarPolicy(Qt::ScrollBarAlwaysOff);
-	textBrowser1->setVerticalScrollBarPolicy(Qt::ScrollBarAlwaysOff);
-	textBrowser1->document()->adjustSize();
-	textBrowser1->setMinimumSize(textBrowser1->document()->size().toSize() + QSize(10, 10));
-	Form2Layout->addWidget( textBrowser1 );
+//	QDialog about_dlg(this);
 
-	layout1 = new QHBoxLayout();
-	layout1->setMargin(0);
-	layout1->setSpacing(6);
+//	QTextBrowser* textBrowser1;
+//	QPushButton* pushButton1;
+//	QVBoxLayout* Form2Layout;
+//	QHBoxLayout* layout1;
+//	QSpacerItem* spacer1;
+//	QSpacerItem* spacer2;
 
-	spacer1 = new QSpacerItem( 40, 20, QSizePolicy::Expanding, QSizePolicy::Minimum );
-	layout1->addItem( spacer1 );
+//    about_dlg.setObjectName("about_box");
+//	about_dlg.setWindowTitle( tr("About Free Music Instrument Tuner") );
 
-	pushButton1 = new QPushButton(&about_dlg);
-	pushButton1->setText( tr( "&OK" ) );
-	layout1->addWidget( pushButton1 );
-	connect(pushButton1, SIGNAL(clicked()), &about_dlg, SLOT(close()));
+//	Form2Layout = new QVBoxLayout( &about_dlg );
+//	Form2Layout->setMargin(11);
+//	Form2Layout->setSpacing(6);
+//	about_dlg.setLayout( Form2Layout );
 
-	spacer2 = new QSpacerItem( 40, 20, QSizePolicy::Expanding, QSizePolicy::Minimum );
-	layout1->addItem( spacer2 );
+//	textBrowser1 = new QTextBrowser( &about_dlg );
+//	textBrowser1->setHtml(text);
+//	textBrowser1->setOpenExternalLinks(true);
+//	textBrowser1->setWordWrapMode(QTextOption::NoWrap);
+//	textBrowser1->setHorizontalScrollBarPolicy(Qt::ScrollBarAlwaysOff);
+//	textBrowser1->setVerticalScrollBarPolicy(Qt::ScrollBarAlwaysOff);
+//	textBrowser1->document()->adjustSize();
+//	textBrowser1->setMinimumSize(textBrowser1->document()->size().toSize() + QSize(10, 10));
+//	Form2Layout->addWidget( textBrowser1 );
 
-	Form2Layout->addLayout( layout1 );
+//	layout1 = new QHBoxLayout();
+//	layout1->setMargin(0);
+//	layout1->setSpacing(6);
 
-	about_dlg.exec();
+//	spacer1 = new QSpacerItem( 40, 20, QSizePolicy::Expanding, QSizePolicy::Minimum );
+//	layout1->addItem( spacer1 );
+
+//	pushButton1 = new QPushButton(&about_dlg);
+//	pushButton1->setText( tr( "&OK" ) );
+//	layout1->addWidget( pushButton1 );
+//	connect(pushButton1, SIGNAL(clicked()), &about_dlg, SLOT(close()));
+
+//	spacer2 = new QSpacerItem( 40, 20, QSizePolicy::Expanding, QSizePolicy::Minimum );
+//	layout1->addItem( spacer2 );
+
+//	Form2Layout->addLayout( layout1 );
+
+//	about_dlg.exec();
 }
 
 CustomInstrumentTunerForm::~CustomInstrumentTunerForm()
@@ -1042,6 +1169,52 @@ CustomInstrumentTunerForm::~CustomInstrumentTunerForm()
 	}
 }
 
+void CustomInstrumentTunerForm::update_localized_note_names()
+{
+	QString transpositionToolTip = tr("Transposition in number of semitones relative to %1.\nUseful to convert note names to a corresponding transposing instrument (e.g. %2 for saxophone, %3 for trumpet).")
+			.arg(QString::fromStdString(h2n(-9, GetNotesName(), 0, CHROMATIC, true))) // C4
+			.arg(QString::fromStdString(h2n(-18, GetNotesName(), 0, CHROMATIC, true))) // Eb3
+			.arg(QString::fromStdString(h2n(-11, GetNotesName(), 0, CHROMATIC, true))); // Bb3
+	m_config_form.textLabel1_7->setToolTip(transpositionToolTip);
+	m_config_form.textLabel1_7->setWhatsThis(transpositionToolTip);
+	m_config_form.ui_spinTransposition->setToolTip(transpositionToolTip);
+	m_config_form.ui_spinTransposition->setWhatsThis(transpositionToolTip);
+	m_config_form.ui_lblTransposition->setToolTip(transpositionToolTip);
+	m_config_form.ui_lblTransposition->setWhatsThis(transpositionToolTip);
+
+	QString a4Name = QString::fromStdString(h2n(0, GetNotesName(), 0, CHROMATIC, true));
+
+	QString a4FreqToolTip = tr("The base tunning frequency (the %1 frequency)")
+			.arg(a4Name);
+	textLabel8->setToolTip(a4FreqToolTip);
+	textLabel8->setWhatsThis(a4FreqToolTip);
+	ui_spinAFreq->setToolTip(a4FreqToolTip);
+	ui_spinAFreq->setWhatsThis(a4FreqToolTip);
+
+	QString showA4OffsetText = tr("Allows to add an offset to the reference %1")
+			.arg(a4Name);
+	m_config_form.ui_chkShowA4Offset->setText(showA4OffsetText);
+
+	QString rangeToolTip = tr("Range of possible notes from the lowest to the highest around the %1 reference note.\nSmaller the range, smaller the CPU usage.")
+			.arg(a4Name);
+	m_config_form.textLabel7->setToolTip(rangeToolTip);
+	m_config_form.textLabel7->setWhatsThis(rangeToolTip);
+
+	QString minHTToolTip = tr("Lowest semitone from the %1 reference note.\nIt can useful to put it higher than -35 to avoid disturbance from the sector alimentation (~50hz).")
+			.arg(a4Name);
+	m_config_form.ui_spinMinHT->setToolTip(minHTToolTip);
+	m_config_form.ui_spinMinHT->setWhatsThis(minHTToolTip);
+	m_config_form.ui_txtMinHT->setToolTip(minHTToolTip);
+	m_config_form.ui_txtMinHT->setWhatsThis(minHTToolTip);
+
+	QString maxHTToolTip = tr("Highest semitone from the %1 reference note.")
+			.arg(a4Name);
+		m_config_form.ui_spinMaxHT->setToolTip(maxHTToolTip);
+	m_config_form.ui_spinMaxHT->setWhatsThis(maxHTToolTip);
+	m_config_form.ui_txtMaxHT->setToolTip(maxHTToolTip);
+	m_config_form.ui_txtMaxHT->setWhatsThis(maxHTToolTip);
+}
+
 /*
 bool displayInBrowser(const QString& theURL)
 {
