@@ -21,9 +21,9 @@
 #ifndef _CustomInstrumentTunerForm_h_
 #define _CustomInstrumentTunerForm_h_
 
-#include "InstrumentTunerForm.h"
+#include "ui_InstrumentTunerForm.h"
 
-#include "config.h"
+// #include "config.h"
 
 #include <deque>
 using namespace std;
@@ -40,7 +40,7 @@ using namespace std;
 using namespace Music;
 #include "AutoQSettings.h"
 #include "CaptureThread.h"
-#include "ConfigForm.h"
+#include "ui_ConfigForm.h"
 #include "LatencyMonoQuantizer.h"
 #include "DummyMonoQuantizer.h"
 #include "modules/DialView.h"
@@ -53,15 +53,26 @@ using namespace Music;
 #include "modules/GLFT.h"
 #include "modules/GLStatistics.h"
 
-class CustomInstrumentTunerForm : public InstrumentTunerForm
+class CustomConfigForm : public QDialog, public Ui_ConfigForm
+{
+	Q_OBJECT
+
+public:
+	CustomConfigForm(QWidget* parent = 0)
+	{
+        Q_UNUSED(parent)
+		setupUi(this);
+	}
+};
+
+class CustomInstrumentTunerForm : public QMainWindow, public Ui_InstrumentTunerForm
 {
 	Q_OBJECT
 
   public:
-	ConfigForm	m_config_form;
+	CustomConfigForm m_config_form;
 
 	CaptureThread m_capture_thread;
-	virtual void pause(bool on);
 	CombedFT* m_algo_combedfft;
 
 	DialView* m_dialTune;
@@ -84,30 +95,14 @@ class CustomInstrumentTunerForm : public InstrumentTunerForm
 	CustomInstrumentTunerForm();
 	AutoQSettings m_settings;
 	void loadSettings();
-	virtual void saveSettings();
-	virtual void restoreFactorySettings();
 
 	virtual void resizeEvent(QResizeEvent* e);
 	virtual void keyPressEvent(QKeyEvent * e);
 
-	virtual void update_views();
-	virtual void configure();
-	virtual void configure_ok();
-	virtual void errorRaised(const QString& error);
-	virtual void samplingRateChanged(int sampling_rate);
-	virtual void noteRangeChanged();
-	virtual void transportChanged(const QString& name);
-	virtual void selectTransport(const QString & name);
-	virtual void autoDetectTransport();
-	virtual void tuningFreqChanged(float);
-	virtual void ui_spinAFreq_valueChanged(int);
-	virtual void ui_spinAOffset_valueChanged(int);
-
 	void toggleFullScreen();
 
 	QTime m_time_refresh;
 	QTime m_time_refresh_views;
-	void refresh();
 	QTimer m_timer_refresh;
 	double m_last_refresh;
 
@@ -121,16 +116,37 @@ class CustomInstrumentTunerForm : public InstrumentTunerForm
 	LatencyMonoQuantizer m_latency_quantizer;
 	DummyMonoQuantizer m_dummy_quantizer;
 	MonoQuantizer* m_quantizer;
-	virtual void noteStarted(double freq, double dt);
-	virtual void noteFinished(double freq, double dt);
 
 	virtual void refresh_views();
 	void refresh_data_sample();
 	void refresh_data_harmonics();
 
 	// the main function
+public slots:
 	virtual void helpAbout();
+	virtual void configure();
+	virtual void pause(bool on);
+	virtual void ui_spinAFreq_valueChanged(int);
+	virtual void ui_spinAOffset_valueChanged(int);
+	virtual void saveSettings();
+	virtual void samplingRateChanged(int sampling_rate);
+	virtual void errorRaised(const QString& error);
+	virtual void transportChanged(const QString& name);
+	virtual void noteStarted(double freq, double dt);
+	virtual void noteFinished(double freq, double dt);
+	virtual void update_views();
+	virtual void tuningFreqChanged(float);
+	virtual void configure_ok();
+    virtual void configure_cancel();
+	virtual void restoreFactorySettings();
+	virtual void noteRangeChanged();
+	virtual void transpositionChanged();
+	virtual void selectTransport(const QString & name);
+	virtual void autoDetectTransport();
+	void refresh();
+	void update_localized_note_names();
 
+public:
 	~CustomInstrumentTunerForm();
 };
 
