@@ -23,7 +23,7 @@
 
 #include <deque>
 using namespace std;
-#include <qgl.h>
+#include <QOpenGLWidget>
 #include <qspinbox.h>
 #include <qsettings.h>
 #include <qaction.h>
@@ -31,11 +31,13 @@ class QTimer;
 #include <Music/Music.h>
 #include "View.h"
 
-class GLStatistics : public QGLWidget, public View
+class GLStatistics : public QOpenGLWidget, public View
 {
 	Q_OBJECT
 
-	virtual void mouseReleaseEvent(QMouseEvent* e){View::mouseReleaseEvent(e);}
+    QFont m_font;
+
+    virtual void mouseReleaseEvent(QMouseEvent* e){View::mouseReleaseEvent(e);}
 
 	void drawTicksCent(int r, int dx, int dy);
 	void drawTextTickCent(int r, int dx);
