@@ -161,6 +161,7 @@ using namespace std;
 #else
 #include <qfiledialog.h>
 #endif
+#include <qdir.h>
 #include <qmessagebox.h>
 #include <qregexp.h>
 #include <qimage.h>
@@ -169,11 +170,13 @@ using namespace std;
 #include <Music/Music.h>
 using namespace Music;
 
+#include "../qthelper.h"
+
 // ---------------------- MScale ------------------------------
 
 void MScale::load_scala(const QString& file_name)
 {
-	ifstream file(file_name.toAscii().constData());
+    ifstream file(file_name.toLatin1().constData());
 
 	if(!file.is_open())
 		throw MicrotonalView::tr("Unkown filename: '")+file_name+"'";
@@ -243,7 +246,7 @@ MScale::MScale(const QString& file_name, FileType type)
 	if(type==SCALA)	load_scala(file_name);
 	else
 	{
-		cerr << "MicrotonalView::Scale::Scale unsupported file type '" << type << "'" << endl;
+        cout << "MicrotonalView::Scale::Scale unsupported file type '" << type << "'" << endl;
 	}
 }
 
@@ -258,17 +261,17 @@ QRoot::QRoot(MicrotonalView* view, int ht)
 : QPushButton(view)
 , m_ht(ht)
 {
-//	cerr << "QRoot::QRoot " << m_ht << endl;
+//	cout << "QRoot::QRoot " << m_ht << endl;
 
 // 	if(ht>8) ht+=12;
 
 	connect(this, SIGNAL(clicked()), this, SLOT(clicked2()));
 	connect(this, SIGNAL(rootClicked(int)), view, SLOT(selectRoot(int)));
 	setFlat(true);
-	setText(QString::fromStdString(h2n(ht, GetNotesName(), GetTonality(), false)));
+	setText(QString::fromStdString(h2n(ht, GetNotesName(), GetTransposition(), false)));
 	setCheckable(true);
-	setSizePolicy(QSizePolicy(QSizePolicy::Fixed, QSizePolicy::Fixed));
-	setFixedWidth(35);		// TODO
+	setSizePolicy(QSizePolicy(QSizePolicy::Minimum, QSizePolicy::Fixed));
+	setMinimumWidth(55);		// TODO
 	setFocusPolicy(Qt::NoFocus);
 }
 void QRoot::clicked2()
@@ -292,8 +295,8 @@ MicrotonalView::MicrotonalView(QWidget* parent)
 	// settings
 	QPixmap img;
 	img.loadFromData(g_icon_ji, sizeof(g_icon_ji), "PNG");
-	setting_show->setIcon(QIcon(img));
-	setting_show->setChecked(false);
+    setting_show->setIcon(QIcon(":/fmit/ui/images/module_microtonal.svg"));
+    setting_show->setChecked(false);
 	hide();
 
 	QHBoxLayout* octaveActionLayout = new QHBoxLayout(&m_popup_menu);
@@ -326,7 +329,7 @@ MicrotonalView::MicrotonalView(QWidget* parent)
 
 	setting_loadScale = new QAction(tr("Load Scala file ..."), this);
 	m_popup_menu.addAction(setting_loadScale);
-	connect(setting_loadScale, SIGNAL(activated()), this, SLOT(loadScale()));
+    connect(setting_loadScale, SIGNAL(triggered()), this, SLOT(loadScale()));
 
 	m_popup_menu.addMenu(&ui_scale_menu);
 
@@ -352,6 +355,7 @@ MicrotonalView::MicrotonalView(QWidget* parent)
 	setMaximumHeight(ui_scale->maximumHeight()+ui_ratios->maximumHeight()+20);
 
 	load_default_scales();
+	load_installed_scales();
 
 	refreshScaleList();
 
@@ -381,14 +385,20 @@ void MicrotonalView::load()
 		try
 		{
 			MScale* scale = new MScale(*it, MScale::SCALA);
-			setting_scales.push_back(scale);
+			bool new_one = true;
+			for(size_t i=0; new_one && i<setting_scales.size(); i++)
+				new_one = *scale != *(setting_scales[i]);
+			if (new_one)
+				setting_scales.push_back(scale);
 		}
-		catch(QString error){cerr << "MicrotonalView::load " << error.toStdString() << endl;}
+        catch(QString error){cout << "MicrotonalView::load " << error.toStdString() << endl;}
 	}
 	refreshScaleList();
 
+    QString fmitprefix(STR(PREFIX));
+
 	selectScale(s_settings->value("selectedScale", "default").toString());
-	setting_lastScalesDirectory = s_settings->value("lastScalesDirectory", ".").toString();
+	setting_lastScalesDirectory = s_settings->value("lastScalesDirectory", fmitprefix+"/share/fmit/scales").toString();
 	selectRoot(s_settings->value("selectedRoot", m_roots[0]->m_ht).toInt());
 }
 void MicrotonalView::clearSettings()
@@ -476,7 +486,7 @@ void MicrotonalView::selectScale(const QString& name)
 
 	if(index==-1)
 	{
-		cerr << "MicrotonalView::selectScale unknown scale '" << name.toStdString() << "'" << endl;
+        cout << "MicrotonalView::selectScale unknown scale '" << name.toStdString() << "'" << endl;
 		return;
 	}
 
@@ -504,7 +514,7 @@ int MicrotonalView::getIndex(MScale* scale)
 void MicrotonalView::notesNameChanged()
 {
 	for(int i=0; i<13; i++)
-		m_roots[i]->setText(QString::fromStdString(h2n(m_roots[i]->m_ht, GetNotesName(), GetTonality(), false)));
+		m_roots[i]->setText(QString::fromStdString(h2n(m_roots[i]->m_ht, GetNotesName(), GetTransposition(), false)));
 }
 
 void MicrotonalView::keepRootToLeft(bool keep)
@@ -540,7 +550,7 @@ void MicrotonalView::updateCursor(float freq)
 
 void MicrotonalView::selectRoot(int ht)
 {
-//	cerr << "MicrotonalView::selectRoot " << ht << endl;
+//	cout << "MicrotonalView::selectRoot " << ht << endl;
 
 	if(ht==setting_selectedRoot)
 	{
@@ -811,7 +821,7 @@ void MicrotonalView::loadScale()
 		setting_lastScalesDirectory = dlg_file.directory().path();
 #endif
 		s_settings->setValue("MicrotonalView_lastScalesDirectory", setting_lastScalesDirectory);
-//		cerr << "setting_lastScalesDirectory=" << setting_lastScalesDirectory << endl;
+//		cout << "setting_lastScalesDirectory=" << setting_lastScalesDirectory << endl;
 		try
 		{
 #ifdef QT3_SUPPORT
@@ -869,6 +879,30 @@ void MicrotonalView::load_default_scales()
 	setting_scales.push_back(scale);
 }
 
+void MicrotonalView::load_installed_scales()
+{
+	QString fmitprefix(STR(PREFIX));
+	QDir scales_dir(fmitprefix + "/share/fmit/scales");
+	
+	QStringList scales_files_list = scales_dir.entryList(QDir::Files);
+	for(QStringList::iterator it=scales_files_list.begin(); it!=scales_files_list.end(); ++it)
+	{
+		if(it->contains(QRegExp("\\.scl$")) || it->contains(QRegExp("\\.SCL$")))
+		{
+			try
+			{
+				MScale* scale = new MScale(scales_dir.absoluteFilePath(*it), MScale::SCALA);
+				bool new_one = true;
+				for(size_t i=0; new_one && i<setting_scales.size(); i++)
+					new_one = *scale != *(setting_scales[i]);
+				if (new_one)
+					setting_scales.push_back(scale);
+			}
+		    catch(QString error){cout << "MicrotonalView::load_installed_scales " << error.toStdString() << endl;}
+		}
+	}
+}
+
 // ------------------ MicrotonalView::ScalePreview --------------------
 #ifdef QT3_SUPPORT
 MicrotonalView::ScalePreview::ScalePreview(QWidget* parent)
