@@ -1,6 +1,51 @@
 <?xml version="1.0" encoding="utf-8"?>
 <!DOCTYPE TS>
-<TS version="2.0" language="pt" sourcelanguage="en">
+<TS version="2.1" language="pt" sourcelanguage="en">
+<context>
+    <name>AboutBox</name>
+    <message>
+        <source>About FMIT...</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>About</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>FMIT</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>&lt;version&gt;</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>&lt;!DOCTYPE HTML PUBLIC &quot;-//W3C//DTD HTML 4.0//EN&quot; &quot;http://www.w3.org/TR/REC-html40/strict.dtd&quot;&gt;
+&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
+p, li { white-space: pre-wrap; }
+&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;Ubuntu&apos;; font-size:11pt; font-weight:400; font-style:normal;&quot;&gt;
+&lt;p style=&quot;-qt-paragraph-type:empty; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;br /&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Credits</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>&lt;!DOCTYPE HTML PUBLIC &quot;-//W3C//DTD HTML 4.0//EN&quot; &quot;http://www.w3.org/TR/REC-html40/strict.dtd&quot;&gt;
+&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
+p, li { white-space: pre-wrap; }
+&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;Ubuntu&apos;; font-size:11pt; font-weight:400; font-style:normal;&quot;&gt;
+&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;Most open-source softwares are infeasible without indirect contributions provided through libraries. Thus, big thanks to the following geeks:&lt;br /&gt;&lt;br /&gt;- dsboger for so many little and usefull changes, updates, packaging, etc.&lt;/p&gt;
+&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;- Florian Hars for the tunning scales&lt;/p&gt;
+&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;- Arnout Engelen for the JACK issues&lt;/p&gt;
+&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;- John Anderson for the microtonal module idea&lt;/p&gt;
+&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;- Scott Bahling for the scales in cents&lt;/p&gt;
+&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;- Jacob Shapiro for his help to make FMIT working under Windows/Cygwin.&lt;/p&gt;
+&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;br /&gt;- Translators: Omega9 (Russian), skarmoutsosv (Greek), Pindaro and dsboger (Portuguese and Brazilian Portuguese), Florian Maier (German).&lt;br /&gt;&lt;br /&gt;- &lt;a href=&quot;http://www.fftw.org/&quot;&gt;&lt;span style=&quot; text-decoration: underline; color:#0000ff;&quot;&gt;FFTW3&lt;/span&gt;&lt;/a&gt;&apos; for the very Fast Fourier Transform.&lt;br /&gt;&lt;br /&gt;- &lt;a href=&quot;http://www.qt.io/&quot;&gt;&lt;span style=&quot; text-decoration: underline; color:#0000ff;&quot;&gt;Qt&lt;/span&gt;&lt;/a&gt;&apos;s team for the GUI library.&lt;br /&gt;&lt;br /&gt;Any contribution of any sort is very welcome!&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
 <context>
     <name>ConfigForm</name>
     <message>
@@ -52,33 +97,6 @@
         <source>Meantone (1/4)</source>
         <translation type="unfinished"></translation>
     </message>
-    <message>
-        <source>The used tonality.
-Useful to convert note names to a corresponding instrument tonality (e.g. Eb for saxophone, Bb for trumpet).</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Tonality</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>C (Do)</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Bb (Sib)</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Eb (Mib)</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Use anglo-saxon or latin note names:
-anglo-saxon: C D E F G A B
-latin: Do Re Mi Fa Sol La Si</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>Note names</source>
         <translation type="unfinished"></translation>
@@ -91,19 +109,6 @@ latin: Do Re Mi Fa Sol La Si</source>
         <source>Latin</source>
         <translation type="unfinished"></translation>
     </message>
-    <message>
-        <source>Show the spin box for the A4 offset</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>&lt;!DOCTYPE HTML PUBLIC &quot;-//W3C//DTD HTML 4.0//EN&quot; &quot;http://www.w3.org/TR/REC-html40/strict.dtd&quot;&gt;
-&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
-p, li { white-space: pre-wrap; }
-&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;Sans Serif&apos;; font-size:9pt; font-weight:400; font-style:normal;&quot;&gt;
-&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;To get more options:&lt;/span&gt;&lt;/p&gt;
-&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;Right-click every view to show up their properties!&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>Capture System</source>
         <translation type="unfinished"></translation>
@@ -178,7 +183,7 @@ p, li { white-space: pre-wrap; }
     </message>
     <message>
         <source>default</source>
-        <translation type="unfinished"></translation>
+        <translation>default</translation>
     </message>
     <message>
         <source>The chosen sampling rate.
@@ -242,24 +247,10 @@ Can be increased to get less CPU usage (but less temporal precision).</source>
         <source> ms</source>
         <translation type="unfinished"></translation>
     </message>
-    <message>
-        <source>Range of possible notes from the lowest to the highest around the A4 reference note.
-Smaller the range, smaller the CPU usage.</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>Notes range</source>
         <translation type="unfinished"></translation>
     </message>
-    <message>
-        <source>Lowest semitone from the A4 reference note.
-It can useful to put it higher than -35 to avoid disturbance from the sector alimentation (~50hz).</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Highest semitone from the A4 reference note.</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>Filter the sound below the lowest semitone and above the highest semitone to avoid artefacts and noises in all the following steps of the sound analysis.</source>
         <translation type="unfinished"></translation>
@@ -387,6 +378,40 @@ The smaller the value, the faster the tuner. However, by decreasing the value, t
         <source>&amp;Cancel</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>Qt</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>&lt;!DOCTYPE HTML PUBLIC &quot;-//W3C//DTD HTML 4.0//EN&quot; &quot;http://www.w3.org/TR/REC-html40/strict.dtd&quot;&gt;
+&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
+p, li { white-space: pre-wrap; }
+&lt;/style&gt;&lt;/head&gt;&lt;body&gt;
+&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;To get more options, right-click every view to show up their properties!&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>German</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Use localized note names. e.g.:
+anglo-saxon: C D E F G A B
+latin: Do Re Mi Fa Sol La Si</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Hindustani</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Byzantine</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Transposition</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>CustomInstrumentTunerForm</name>
@@ -405,40 +430,31 @@ Você tem certeza que quer perder todas as configurações atuais?</translation>
         <translation>Você quer reiniciar o FMIT agora para voltar suas configurações padrões</translation>
     </message>
     <message>
-        <source>&lt;h3&gt;Version </source>
-        <translation>&lt;h3&gt;Versão </translation>
+        <source>The base tunning frequency (the %1 frequency)</source>
+        <translation type="unfinished"></translation>
     </message>
     <message>
-        <source>&lt;/h3&gt;&lt;p&gt;&lt;h3&gt;Website:&lt;/h3&gt;&lt;p&gt;homepage: &lt;a href=&quot;http://home.gna.org/fmit&quot;&gt;http://home.gna.org/fmit&lt;/a&gt;</source>
-        <translation>&lt;/h3&gt;&lt;p&gt;&lt;h3&gt;Website:&lt;/h3&gt;&lt;p&gt;homepage: &lt;a href=&quot;http://home.gna.org/fmit&quot;&gt;http://home.gna.org/fmit&lt;/a&gt;</translation>
+        <source>Allows to add an offset to the reference %1</source>
+        <translation type="unfinished"></translation>
     </message>
     <message>
-        <source>&lt;p&gt;development site: &lt;a href=&quot;http://gna.org/projects/fmit&quot;&gt;http://gna.org/projects/fmit&lt;/a&gt;</source>
-        <translation>&lt;p&gt;Site de desenvolvimento: &lt;a href=&quot;http://gna.org/projects/fmit&quot;&gt;http://gna.org/projects/fmit&lt;/a&gt;</translation>
+        <source>Range of possible notes from the lowest to the highest around the %1 reference note.
+Smaller the range, smaller the CPU usage.</source>
+        <translation type="unfinished"></translation>
     </message>
     <message>
-        <source>&lt;p&gt;donation link: &lt;a href=&quot;http://home.gna.org/fmit/donation.html&quot;&gt;http://home.gna.org/fmit/donation.html&lt;/a&gt;</source>
-        <translation>&lt;p&gt;link para doar: &lt;a href=&quot;http://home.gna.org/fmit/donation.html&quot;&gt;http://home.gna.org/fmit/donation.html&lt;/a&gt;</translation>
+        <source>Lowest semitone from the %1 reference note.
+It can useful to put it higher than -35 to avoid disturbance from the sector alimentation (~50hz).</source>
+        <translation type="unfinished"></translation>
     </message>
     <message>
-        <source>&lt;p&gt;&lt;h3&gt;Author:&lt;/h3&gt;&lt;p&gt;Gilles Degottex &lt;a href=&quot;mailto:gilles.degottex@gmail.com&quot;&gt;gilles.degottex@gmail.com&lt;/a&gt;</source>
-        <translation>&lt;p&gt;&lt;h3&gt;Author:&lt;/h3&gt;&lt;p&gt;Gilles Degottex &lt;a href=&quot;mailto:gilles.degottex@gmail.com&quot;&gt;gilles.degottex@gmail.com&lt;/a&gt;</translation>
+        <source>Highest semitone from the %1 reference note.</source>
+        <translation type="unfinished"></translation>
     </message>
     <message>
-        <source>&lt;p&gt;&lt;h3&gt;Packager:&lt;/h3&gt;&lt;p&gt;</source>
-        <translation>&lt;p&gt;&lt;h3&gt;Packager:&lt;/h3&gt;&lt;p&gt;</translation>
-    </message>
-    <message>
-        <source>about_box</source>
-        <translation>about_box</translation>
-    </message>
-    <message>
-        <source>About Free Music Instrument Tuner</source>
-        <translation>Sobre o Free Music Instrument Tuner</translation>
-    </message>
-    <message>
-        <source>&amp;OK</source>
-        <translation>&amp;OK</translation>
+        <source>Transposition in number of semitones relative to %1.
+Useful to convert note names to a corresponding transposing instrument (e.g. %2 for saxophone, %3 for trumpet).</source>
+        <translation type="unfinished"></translation>
     </message>
 </context>
 <context>
@@ -540,6 +556,10 @@ Você tem certeza que quer perder todas as configurações atuais?</translation>
         <source>Number of harmonics</source>
         <translation>Número de harmonicas</translation>
     </message>
+    <message>
+        <source>Harmonics&apos; amplitude</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>GLGraph</name>
@@ -570,10 +590,6 @@ Você tem certeza que quer perder todas as configurações atuais?</translation>
 </context>
 <context>
     <name>GLSample</name>
-    <message>
-        <source>Wave form</source>
-        <translation>Forma de onda</translation>
-    </message>
     <message>
         <source>Show fading</source>
         <translation>Mostrar o decaimento</translation>
@@ -582,6 +598,14 @@ Você tem certeza que quer perder todas as configurações atuais?</translation>
         <source>Number of fading</source>
         <translation>Número de decaimento</translation>
     </message>
+    <message>
+        <source>Waveform</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Waveform&apos;s period</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>GLStatistics</name>
@@ -835,8 +859,12 @@ green   : a note is beeing analyzed and analysis conditions are OK.</source>
 <context>
     <name>QObject</name>
     <message>
-        <source>Show &quot;%1&quot; view</source>
-        <translation>Mostrar &quot;%1&quot; vista</translation>
+        <source>default</source>
+        <translation type="unfinished">default</translation>
+    </message>
+    <message>
+        <source>%1</source>
+        <translation type="unfinished"></translation>
     </message>
 </context>
 </TS>
